# bread-tools
Basic processing tools in common algorithms.
this is a package, use  ```pip install bread-tools```  to install it.

---
### 1. Gen requirements.txt.
 ``` sh gen_requirements.sh ```

### 2. Run all test cases.
 ``` sh run_pytest.sh ```

### 3. Build package and upload it.
 ``` sh gen_to_pypi.sh ```

